<!DOCTYPE html>
<html>
  <head>
    <meta name="viewport" content="initial-scale=1.0, user-scalable=no">
    <meta charset="utf-8">
    <title>County Overlay</title>
    <link rel="stylesheet" href="CQX_StyleSheet-new.css" type="text/css" />

    <style>
      html, body, #map-canvas {
        height: 100%;
        margin: 0px;
        padding: 0px
      }
      html, body, #countySelection{width: 100%; height: 100%}
    </style>


    <script src="https://maps.googleapis.com/maps/api/js?v=3.exp"></script>

    <script language="javascript" type="text/javascript">

    var map;
    var infoWindow;
    var theCountyMarkers = new Array();
    var theCountyValues = new Array();
    var cqxUrl = "http://www.no5w.com";


    var stateFullName = "Illinois";
    var qsoPartyUrl = "http://www.w9awe.org/ILQP.html";
    var overlayUrl = "http://www.no5w.com/OverlayIllinoisRev3.kml";

    /*-----------------------------------------------------------------------------------------------------
     PromoControl: constructor for the QSO Party promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function PromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access QSO Party home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '24px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String(stateFullName) + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(qsoPartyUrl));
      });
    }//PromoControl constructor

    /*-----------------------------------------------------------------------------------------------------
     CQXPromoControl: constructor for the CQ/X promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function CQXPromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access CQ/X home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '12px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String("CQ/X de NO5W") + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(cqxUrl));
      });
    }//CQXPromoControl constructor

/*-----------------------------------------------------------------------------------------------------
 addMarker: function for adding a county marker
-----------------------------------------------------------------------------------------------------*/
function addMarker(lat, lon, desc, aval) {
  var markerLatLng = new google.maps.LatLng(lat, lon);

  var markerOptions = {
    flat: true,
    map: map,
    optimized: false,
    position: markerLatLng,
    visible: true,
    title: desc
    };
  var marker = new google.maps.Marker(markerOptions);
  theCountyMarkers.push(marker);
  theCountyValues.push(aval);

  }//addMarker

/*-----------------------------------------------------------------------------------------------------
 removeMarkers: function for removing all of the current markers
 -----------------------------------------------------------------------------------------------------*/
function removeMarkers() {
  for(var i=0;i<theCountyMarkers.length;i++) theCountyMarkers[i].setMap(null);
  }//removeMarkers     

/*-----------------------------------------------------------------------------------------------------
 populateCountySelection: function for building the county selection
 -----------------------------------------------------------------------------------------------------*/
function populateCountySelection() {
  var countySelection = document.getElementById("countySelection");
          
  countySelection.options.length = 0;
  theCountyMarkers.length = 0;
  theCountyValues.length = 0;

  countySelection.options[0] = new Option("Adams", "adam");
  countySelection.options[1] = new Option("Alexander", "alex");
  countySelection.options[2] = new Option("Bond", "bond");
  countySelection.options[3] = new Option("Boone", "boon");
  countySelection.options[4] = new Option("Brown", "brow");
  countySelection.options[5] = new Option("Bureau", "buro");
  countySelection.options[6] = new Option("Calhoun", "calh");
  countySelection.options[7] = new Option("Carroll", "carr");
  countySelection.options[8] = new Option("Cass", "cass");
  countySelection.options[9] = new Option("Champaign", "cham");
  countySelection.options[10] = new Option("Christian", "chrs");
  countySelection.options[11] = new Option("Clark", "clrk");
  countySelection.options[12] = new Option("Clay", "clay");
  countySelection.options[13] = new Option("Clinton", "clnt");
  countySelection.options[14] = new Option("Coles", "cole");
  countySelection.options[15] = new Option("Cook", "cook");
  countySelection.options[16] = new Option("Crawford", "craw");
  countySelection.options[17] = new Option("Cumberland", "cumb");
  countySelection.options[18] = new Option("DeKalb", "deka");
  countySelection.options[19] = new Option("DeWitt", "dewt");
  countySelection.options[20] = new Option("Douglas", "doug");
  countySelection.options[21] = new Option("DuPage", "dupg");
  countySelection.options[22] = new Option("Edgar", "edgr");
  countySelection.options[23] = new Option("Edwards", "edwa");
  countySelection.options[24] = new Option("Effingham", "effg");
  countySelection.options[25] = new Option("Fayette", "faye");
  countySelection.options[26] = new Option("Ford", "ford");
  countySelection.options[27] = new Option("Franklin", "frnk");
  countySelection.options[28] = new Option("Fulton", "fult");
  countySelection.options[29] = new Option("Gallatin", "gall");
  countySelection.options[30] = new Option("Greene", "gree");
  countySelection.options[31] = new Option("Grundy", "grun");
  countySelection.options[32] = new Option("Hamilton", "haml");
  countySelection.options[33] = new Option("Hancock", "hanc");
  countySelection.options[34] = new Option("Hardin", "hard");
  countySelection.options[35] = new Option("Henderson", "hndr");
  countySelection.options[36] = new Option("Henry", "henr");
  countySelection.options[37] = new Option("Iroquois", "iroq");
  countySelection.options[38] = new Option("Jackson", "jack");
  countySelection.options[39] = new Option("Jasper", "jasp");
  countySelection.options[40] = new Option("Jefferson", "jeff");
  countySelection.options[41] = new Option("Jersey", "jers");
  countySelection.options[42] = new Option("JoDaviess", "joda");
  countySelection.options[43] = new Option("Johnson", "john");
  countySelection.options[44] = new Option("Kane", "kane");
  countySelection.options[45] = new Option("Kankakee", "kank");
  countySelection.options[46] = new Option("Kendall", "kend");
  countySelection.options[47] = new Option("Knox", "knox");
  countySelection.options[48] = new Option("Lake", "lake");
  countySelection.options[49] = new Option("LaSalle", "lasa");
  countySelection.options[50] = new Option("Lawrence", "lawr");
  countySelection.options[51] = new Option("Lee", "lee");
  countySelection.options[52] = new Option("Livingston", "livg");
  countySelection.options[53] = new Option("Logan", "logn");
  countySelection.options[54] = new Option("Macon", "macn");
  countySelection.options[55] = new Option("Macoupin", "mcpn");
  countySelection.options[56] = new Option("Madison", "madn");
  countySelection.options[57] = new Option("Marion", "mari");
  countySelection.options[58] = new Option("Marshall", "mshl");
  countySelection.options[59] = new Option("Mason", "masn");
  countySelection.options[60] = new Option("Massac", "mssc");
  countySelection.options[61] = new Option("McDonough", "mcdn");
  countySelection.options[62] = new Option("McHenry", "mche");
  countySelection.options[63] = new Option("McLean", "mcln");
  countySelection.options[64] = new Option("Menard", "mnrd");
  countySelection.options[65] = new Option("Mercer", "mrcr");
  countySelection.options[66] = new Option("Monroe", "mnro");
  countySelection.options[67] = new Option("Montgomery", "mntg");
  countySelection.options[68] = new Option("Morgan", "morg");
  countySelection.options[69] = new Option("Moultrie", "moul");
  countySelection.options[70] = new Option("Ogle", "ogle");
  countySelection.options[71] = new Option("Peoria", "peor");
  countySelection.options[72] = new Option("Perry", "perr");
  countySelection.options[73] = new Option("Piatt", "piat");
  countySelection.options[74] = new Option("Pike", "pike");
  countySelection.options[75] = new Option("Pope", "pope");
  countySelection.options[76] = new Option("Pulaski", "pula");
  countySelection.options[77] = new Option("Putnam", "putn");
  countySelection.options[78] = new Option("Randolph", "rand");
  countySelection.options[79] = new Option("Richland", "rich");
  countySelection.options[80] = new Option("RockIsland", "rock");
  countySelection.options[81] = new Option("Saline", "sali");
  countySelection.options[82] = new Option("Sangamon", "sang");
  countySelection.options[83] = new Option("Schuyler", "schy");
  countySelection.options[84] = new Option("Scott", "scot");
  countySelection.options[85] = new Option("Shelby", "shel");
  countySelection.options[86] = new Option("St.Clair", "scla");
  countySelection.options[87] = new Option("Stark", "star");
  countySelection.options[88] = new Option("Stephenson", "step");
  countySelection.options[89] = new Option("Tazewell", "tazw");
  countySelection.options[90] = new Option("Union", "unio");
  countySelection.options[91] = new Option("Vermilion", "verm");
  countySelection.options[92] = new Option("Wabash", "waba");
  countySelection.options[93] = new Option("Warren", "warr");
  countySelection.options[94] = new Option("Washington", "wash");
  countySelection.options[95] = new Option("Wayne", "wayn");
  countySelection.options[96] = new Option("White", "whit");
  countySelection.options[97] = new Option("Whiteside", "wtsd");
  countySelection.options[98] = new Option("Will", "will");
  countySelection.options[99] = new Option("Williamson", "wmsn");
  countySelection.options[100] = new Option("Winnebago", "wbgo");
  countySelection.options[101] = new Option("Woodford", "wood");
  addMarker(39.97860000, -91.21260000, "Adams", "adam");
  addMarker(37.15280000, -89.32550000, "Alexander", "alex");
  addMarker(38.88440000, -89.44490000, "Bond", "bond");
  addMarker(42.32370000, -88.82320000, "Boone", "boon");
  addMarker(39.97250000, -90.71370000, "Brown", "brow");
  addMarker(41.36690000, -89.51310000, "Bureau", "buro");
  addMarker(39.13430000, -90.69380000, "Calhoun", "calh");
  addMarker(42.06400000, -90.00100000, "Carroll", "carr");
  addMarker(39.99890000, -90.28900000, "Cass", "cass");
  addMarker(40.13990000, -88.19610000, "Champaign", "cham");
  addMarker(39.58610000, -89.27960000, "Christian", "chrs");
  addMarker(39.32240000, -87.77280000, "Clark", "clrk");
  addMarker(38.75730000, -88.47360000, "Clay", "clay");
  addMarker(38.57960000, -89.42270000, "Clinton", "clnt");
  addMarker(39.52970000, -88.21620000, "Coles", "cole");
  addMarker(41.81190000, -87.89380000, "Cook", "cook");
  addMarker(39.01410000, -87.73130000, "Crawford", "craw");
  addMarker(39.27480000, -88.23950000, "Cumberland", "cumb");
  addMarker(41.89090000, -88.76520000, "DeKalb", "deka");
  addMarker(40.16600000, -88.86190000, "DeWitt", "dewt");
  addMarker(39.76580000, -88.20520000, "Douglas", "doug");
  addMarker(41.83810000, -88.08920000, "DuPage", "dupg");
  addMarker(39.67990000, -87.75020000, "Edgar", "edgr");
  addMarker(38.41310000, -88.04430000, "Edwards", "edwa");
  addMarker(39.06360000, -88.58380000, "Effingham", "effg");
  addMarker(38.97710000, -88.97550000, "Fayette", "faye");
  addMarker(40.69810000, -88.19610000, "Ford", "ford");
  addMarker(37.99430000, -88.94160000, "Franklin", "frnk");
  addMarker(40.44930000, -90.16180000, "Fulton", "fult");
  addMarker(37.74460000, -88.20170000, "Gallatin", "gall");
  addMarker(39.31970000, -90.38520000, "Greene", "gree");
  addMarker(41.28530000, -88.41840000, "Grundy", "grun");
  addMarker(38.08160000, -88.53860000, "Hamilton", "haml");
  addMarker(40.41610000, -91.20580000, "Hancock", "hanc");
  addMarker(37.50080000, -88.23830000, "Hardin", "hard");
  addMarker(40.85260000, -90.98580000, "Henderson", "hndr");
  addMarker(41.36680000, -90.14720000, "Henry", "henr");
  addMarker(40.74810000, -87.82880000, "Iroquois", "iroq");
  addMarker(37.75870000, -89.41580000, "Jackson", "jack");
  addMarker(39.01100000, -88.15380000, "Jasper", "jasp");
  addMarker(38.30060000, -88.92440000, "Jefferson", "jeff");
  addMarker(39.09280000, -90.37470000, "Jersey", "jers");
  addMarker(42.35090000, -90.28800000, "JoDaviess", "joda");
  addMarker(37.44730000, -88.87680000, "Johnson", "john");
  addMarker(41.93700000, -88.42020000, "Kane", "kane");
  addMarker(41.14650000, -87.88900000, "Kankakee", "kank");
  addMarker(41.59190000, -88.42790000, "Kendall", "kend");
  addMarker(40.93220000, -90.21440000, "Knox", "knox");
  addMarker(42.32440000, -87.97980000, "Lake", "lake");
  addMarker(41.27870000, -88.87670000, "LaSalle", "lasa");
  addMarker(38.71030000, -87.70430000, "Lawrence", "lawr");
  addMarker(41.74860000, -89.28550000, "Lee", "lee");
  addMarker(40.86520000, -88.58320000, "Livingston", "livg");
  addMarker(40.12110000, -89.37360000, "Logan", "logn");
  addMarker(39.85400000, -88.98150000, "Macon", "macn");
  addMarker(39.26090000, -89.92620000, "Macoupin", "mcpn");
  addMarker(38.82750000, -89.93560000, "Madison", "madn");
  addMarker(38.65010000, -88.91980000, "Marion", "mari");
  addMarker(41.03490000, -89.34290000, "Marshall", "mshl");
  addMarker(40.24420000, -89.97830000, "Mason", "masn");
  addMarker(37.20120000, -88.70960000, "Massac", "mssc");
  addMarker(40.45780000, -90.67770000, "McDonough", "mcdn");
  addMarker(42.32480000, -88.45250000, "McHenry", "mche");
  addMarker(40.51920000, -88.86430000, "McLean", "mcln");
  addMarker(40.03110000, -89.78670000, "Menard", "mnrd");
  addMarker(41.19850000, -90.77400000, "Mercer", "mrcr");
  addMarker(38.30430000, -90.13560000, "Monroe", "mnro");
  addMarker(39.26180000, -89.42160000, "Montgomery", "mntg");
  addMarker(39.69830000, -90.26150000, "Morgan", "morg");
  addMarker(39.61960000, -88.64170000, "Moultrie", "moul");
  addMarker(42.04520000, -89.31360000, "Ogle", "ogle");
  addMarker(40.74420000, -89.71840000, "Peoria", "peor");
  addMarker(38.08470000, -89.35510000, "Perry", "perr");
  addMarker(40.03660000, -88.60290000, "Piatt", "piat");
  addMarker(39.62040000, -90.96800000, "Pike", "pike");
  addMarker(37.33350000, -88.56140000, "Pope", "pope");
  addMarker(37.20140000, -89.10070000, "Pulaski", "pula");
  addMarker(41.21300000, -89.31430000, "Putnam", "putn");
  addMarker(38.01300000, -89.89960000, "Randolph", "rand");
  addMarker(38.70960000, -88.10200000, "Richland", "rich");
  addMarker(41.55490000, -90.61590000, "RockIsland", "rock");
  addMarker(37.75350000, -88.54120000, "Saline", "sali");
  addMarker(39.74860000, -89.60600000, "Sangamon", "sang");
  addMarker(40.13160000, -90.55660000, "Schuyler", "schy");
  addMarker(39.65510000, -90.47340000, "Scott", "scot");
  addMarker(39.43460000, -88.80530000, "Shelby", "shel");
  addMarker(38.44000000, -89.98350000, "St.Clair", "scla");
  addMarker(41.10410000, -89.81210000, "Stark", "star");
  addMarker(42.35080000, -89.66140000, "Stephenson", "step");
  addMarker(40.53380000, -89.59430000, "Tazewell", "tazw");
  addMarker(37.46520000, -89.28170000, "Union", "unio");
  addMarker(40.18000000, -87.73440000, "Vermilion", "verm");
  addMarker(38.40180000, -87.82140000, "Wabash", "waba");
  addMarker(40.84830000, -90.61450000, "Warren", "warr");
  addMarker(38.36580000, -89.42420000, "Washington", "wash");
  addMarker(38.43130000, -88.42500000, "Wayne", "wayn");
  addMarker(38.06970000, -88.14810000, "White", "whit");
  addMarker(41.75760000, -89.93850000, "Whiteside", "wtsd");
  addMarker(41.46510000, -87.89340000, "Will", "will");
  addMarker(37.73000000, -88.93020000, "Williamson", "wmsn");
  addMarker(42.32540000, -89.17060000, "Winnebago", "wbgo");
  addMarker(40.76100000, -89.24670000, "Woodford", "wood");

  countySelection.selectedIndex = 0;
  }

//----------------------------------------------------------------------------------------------------

function initialize() {

  populateCountySelection();

  var mapOptions = {
    zoom: 11
    };

  map = new google.maps.Map(document.getElementById('map-canvas'), mapOptions);

  var stateLayer = new google.maps.KmlLayer({url: overlayUrl, suppressInfoWindows: true});
  stateLayer.setMap(map);

  // Add a listener for the click event.
  google.maps.event.addListener(stateLayer, 'click', showLatLon);

  infoWindow = new google.maps.InfoWindow();

  var promoControlDiv = document.createElement('div');
  var promoControl = new PromoControl(promoControlDiv, map);

  promoControlDiv.index = 1;
  map.controls[google.maps.ControlPosition.TOP_CENTER].push(promoControlDiv);

  var promoCQXControlDiv = document.createElement('div');
  var promoCQXControl = new CQXPromoControl(promoCQXControlDiv, map);

  promoCQXControlDiv.index = 2;
  map.controls[google.maps.ControlPosition.TOP_RIGHT].push(promoCQXControlDiv);

  }

/*-----------------------------------------------------------------------------------------------------
 changeCounty: function processing a county change from the countySelection 
 -----------------------------------------------------------------------------------------------------*/
function changeCounty() {
  removeMarkers();
  var acounty = encodeURIComponent(document.getElementById("countySelection").value);
  var iMark = -1;
  for(i=0;i<theCountyValues.length;i++) {
    if(theCountyValues[i] != acounty) continue;
    iMark = i;
    break;
    }
  if(iMark < 0) return;
  map.setCenter(theCountyMarkers[iMark].getPosition());
  theCountyMarkers[iMark].setMap(map);
  }//function changeCounty

function catchEvent(eventObj, event, eventHandler) {
  if(eventObj.addEventListener) {
    eventObj.addEventListener(event, eventHandler, false);
    }
  else if(eventObj.attachEvent) {
    event = "on" + event;
    eventObj.attachEvent(event, eventHandler);
    }
  }//catchEvent

/*-----------------------------------------------------------------------------------------------------
 set up event handlers when the window loads 
 -----------------------------------------------------------------------------------------------------*/
catchEvent(window, "load", function() {
  document.getElementById("countySelection").onchange=changeCounty;
  });

function showLatLon(event) {

  var nameStr = event.featureData.name; //FullName=Abbrev Num
  var arrayOne = nameStr.split("=");
  var arrayTwo = arrayOne[1].split(" ");

  var contentString = '<b>Clicked on Location</b>' + '<br>' +
                    '<b>LatLon: </b>' + event.latLng.lat() + ',' + event.latLng.lng() + '<br>' +
                    '<b>In County: </b>' + arrayOne[0] + '(' + arrayTwo[0] + ')';

  // Replace the info window's content and position.
  infoWindow.setContent(contentString);
  infoWindow.setPosition(event.latLng);

  infoWindow.open(map);
  }

google.maps.event.addDomListener(window, 'load', initialize);


    </script>
  </head>

  <body>

    <table style="width: 1000px;">
      <tbody>
        <tr style="vertical-align: top;">

          <td>
          <form>
            <div class="elem" style = "width: 120px; height: 700px; margin: 0; padding: 0; overflow:auto;">
              <select id="countySelection" name="county" size='43'>
                <option> </option>
              </select>
            </div>
          </form>
          </td>

          <td>
            <div id="map-canvas" style="width: 880px; height: 700px;"></div>
          </td>
        </tr>
      </tbody>
    </table>

  </body>


</html>

